==> goods-center-api-2.9.85-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemPriceDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import java.io.Serializable;

/**
 * Created by xutao on 2018/12/21.
 */
public class ItemPriceDto implements Serializable {
    private static final long serialVersionUID = -3029836119246660607L;
    //有多个价格
    private boolean hasMultiPrice;

    //最低供应商建议零售价格
    private String minSuggestMarketPrice;
    //最低划线价
    private String minFacePrice;
    //最低供货价
    private String minSalePrice;

    //最高供应商建议零售价格
    private String maxSuggestMarketPrice;
    //最高划线价
    private String maxFacePrice;
    //最高供货价
    private String maxSalePrice;

    public String getMinSuggestMarketPrice() {
        return minSuggestMarketPrice;
    }

    public void setMinSuggestMarketPrice(String minSuggestMarketPrice) {
        this.minSuggestMarketPrice = minSuggestMarketPrice;
    }

    public String getMinFacePrice() {
        return minFacePrice;
    }

    public void setMinFacePrice(String minFacePrice) {
        this.minFacePrice = minFacePrice;
    }

    public String getMinSalePrice() {
        return minSalePrice;
    }

    public void setMinSalePrice(String minSalePrice) {
        this.minSalePrice = minSalePrice;
    }

    public String getMaxSuggestMarketPrice() {
        return maxSuggestMarketPrice;
    }

    public void setMaxSuggestMarketPrice(String maxSuggestMarketPrice) {
        this.maxSuggestMarketPrice = maxSuggestMarketPrice;
    }

    public String getMaxFacePrice() {
        return maxFacePrice;
    }

    public void setMaxFacePrice(String maxFacePrice) {
        this.maxFacePrice = maxFacePrice;
    }

    public String getMaxSalePrice() {
        return maxSalePrice;
    }

    public void setMaxSalePrice(String maxSalePrice) {
        this.maxSalePrice = maxSalePrice;
    }

    public boolean getHasMultiPrice() {
        return hasMultiPrice;
    }

    public void setHasMultiPrice(boolean hasMultiPrice) {
        this.hasMultiPrice = hasMultiPrice;
    }
}

==> goods-center-api-3.0.13-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/item/ItemPriceDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.item;

import java.io.Serializable;

/**
 * Created by xutao on 2018/12/21.
 */
public class ItemPriceDto implements Serializable {
    private static final long serialVersionUID = -3029836119246660607L;
    //有多个价格
    private boolean hasMultiPrice;

    //最低供应商建议零售价格
    private String minSuggestMarketPrice;
    //最低划线价
    private String minFacePrice;
    //最低供货价
    private String minSalePrice;
    //最低供货价
    private String minCostPrice;

    //最高供应商建议零售价格
    private String maxSuggestMarketPrice;
    //最高划线价
    private String maxFacePrice;
    //最高供货价
    private String maxSalePrice;
    //最高供货价
    private String maxCostPrice;

    public String getMinCostPrice() {
        return minCostPrice;
    }

    public void setMinCostPrice(String minCostPrice) {
        this.minCostPrice = minCostPrice;
    }

    public String getMaxCostPrice() {
        return maxCostPrice;
    }

    public void setMaxCostPrice(String maxCostPrice) {
        this.maxCostPrice = maxCostPrice;
    }

    public String getMinSuggestMarketPrice() {
        return minSuggestMarketPrice;
    }

    public void setMinSuggestMarketPrice(String minSuggestMarketPrice) {
        this.minSuggestMarketPrice = minSuggestMarketPrice;
    }

    public String getMinFacePrice() {
        return minFacePrice;
    }

    public void setMinFacePrice(String minFacePrice) {
        this.minFacePrice = minFacePrice;
    }

    public String getMinSalePrice() {
        return minSalePrice;
    }

    public void setMinSalePrice(String minSalePrice) {
        this.minSalePrice = minSalePrice;
    }

    public String getMaxSuggestMarketPrice() {
        return maxSuggestMarketPrice;
    }

    public void setMaxSuggestMarketPrice(String maxSuggestMarketPrice) {
        this.maxSuggestMarketPrice = maxSuggestMarketPrice;
    }

    public String getMaxFacePrice() {
        return maxFacePrice;
    }

    public void setMaxFacePrice(String maxFacePrice) {
        this.maxFacePrice = maxFacePrice;
    }

    public String getMaxSalePrice() {
        return maxSalePrice;
    }

    public void setMaxSalePrice(String maxSalePrice) {
        this.maxSalePrice = maxSalePrice;
    }

    public boolean getHasMultiPrice() {
        return hasMultiPrice;
    }

    public void setHasMultiPrice(boolean hasMultiPrice) {
        this.hasMultiPrice = hasMultiPrice;
    }
}
